import { Command, Element, Operation, Range, Node, NodeEntry } from '../..';
/**
 * The `Editor` interface stores all the state of a Slate editor. It is extended
 * by plugins that wish to add their own helpers and implement new behaviors.
 */
export interface Editor {
    children: Node[];
    selection: Range | null;
    operations: Operation[];
    marks: Record<string, any> | null;
    apply: (operation: Operation) => void;
    exec: (command: Command) => void;
    isInline: (element: Element) => boolean;
    isVoid: (element: Element) => boolean;
    normalizeNode: (entry: NodeEntry) => void;
    onChange: () => void;
    [key: string]: any;
}
export declare const Editor: {
    delete(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        distance?: number | undefined;
        unit?: "character" | "word" | "line" | "block" | undefined;
        reverse?: boolean | undefined;
        hanging?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    insertFragment(editor: Editor, fragment: Node[], options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        hanging?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    insertText(editor: Editor, text: string, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        voids?: boolean | undefined;
    }): void;
    collapse(editor: Editor, options?: {
        edge?: "start" | "end" | "anchor" | "focus" | undefined;
    }): void;
    deselect(editor: Editor): void;
    move(editor: Editor, options?: {
        distance?: number | undefined;
        unit?: "offset" | "character" | "word" | "line" | undefined;
        reverse?: boolean | undefined;
        edge?: "start" | "end" | "anchor" | "focus" | undefined;
    }): void;
    select(editor: Editor, target: import("../location").Location): void;
    setPoint(editor: Editor, props: Partial<import("../point").Point>, options: {
        edge?: "start" | "end" | "anchor" | "focus" | undefined;
    }): void;
    setSelection(editor: Editor, props: Partial<Range>): void;
    unhangRange(editor: Editor, range: Range, options?: {
        voids?: boolean | undefined;
    }): Range;
    insertNodes(editor: Editor, nodes: Editor | Element | import("../text").Text | Node[], options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: ((node: Node) => boolean) | undefined;
        mode?: "highest" | "lowest" | undefined;
        hanging?: boolean | undefined;
        select?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    liftNodes(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: ((node: Node) => boolean) | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        voids?: boolean | undefined;
    }): void;
    mergeNodes(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: ((node: Node) => boolean) | undefined;
        mode?: "highest" | "lowest" | undefined;
        hanging?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    moveNodes(editor: Editor, options: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: ((node: Node) => boolean) | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        to: import("../path").Path;
        voids?: boolean | undefined;
    }): void;
    removeNodes(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: ((node: Node) => boolean) | undefined;
        mode?: "highest" | "lowest" | undefined;
        hanging?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    setNodes(editor: Editor, props: Partial<Editor> | Partial<Element> | Partial<import("../text").Text>, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: ((node: Node) => boolean) | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        hanging?: boolean | undefined;
        split?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    splitNodes(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: ((node: Node) => boolean) | undefined;
        mode?: "highest" | "lowest" | undefined;
        always?: boolean | undefined;
        height?: number | undefined;
        voids?: boolean | undefined;
    }): void;
    unsetNodes(editor: Editor, props: string | string[], options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: ((node: Node) => boolean) | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        split?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    unwrapNodes(editor: Editor, options: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: ((node: Node) => boolean) | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        split?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    wrapNodes(editor: Editor, element: Element, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: ((node: Node) => boolean) | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        split?: boolean | undefined;
        voids?: boolean | undefined;
    }): void;
    above<T extends import("../node").Ancestor>(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: ((node: Node) => boolean) | ((node: Node) => node is T) | undefined;
        mode?: "highest" | "lowest" | undefined;
        voids?: boolean | undefined;
    }): NodeEntry<T> | undefined;
    after(editor: Editor, at: import("../location").Location, options?: {
        distance?: number | undefined;
        unit?: "offset" | "character" | "word" | "line" | "block" | undefined;
    }): import("../point").Point | undefined;
    before(editor: Editor, at: import("../location").Location, options?: {
        distance?: number | undefined;
        unit?: "offset" | "character" | "word" | "line" | "block" | undefined;
    }): import("../point").Point | undefined;
    edges(editor: Editor, at: import("../location").Location): [import("../point").Point, import("../point").Point];
    end(editor: Editor, at: import("../location").Location): import("../point").Point;
    first(editor: Editor, at: import("../location").Location): NodeEntry<Node>;
    fragment(editor: Editor, at: import("../location").Location): import("../node").Descendant[];
    isEnd(editor: Editor, point: import("../point").Point, at: import("../location").Location): boolean;
    isEdge(editor: Editor, point: import("../point").Point, at: import("../location").Location): boolean;
    isStart(editor: Editor, point: import("../point").Point, at: import("../location").Location): boolean;
    last(editor: Editor, at: import("../location").Location): NodeEntry<Node>;
    leaf(editor: Editor, at: import("../location").Location, options?: {
        depth?: number | undefined;
        edge?: "start" | "end" | undefined;
    }): NodeEntry<import("../text").Text>;
    levels(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        reverse?: boolean | undefined;
        voids?: boolean | undefined;
    }): Iterable<NodeEntry<Node>>;
    next<T_1 extends Node>(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: ((node: Node) => boolean) | ((node: Node) => node is T_1) | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        voids?: boolean | undefined;
    }): NodeEntry<T_1> | undefined;
    node(editor: Editor, at: import("../location").Location, options?: {
        depth?: number | undefined;
        edge?: "start" | "end" | undefined;
    }): NodeEntry<Node>;
    nodes<T_2 extends Node>(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | import("../location").Span | undefined;
        match?: ((node: Node) => boolean) | ((node: Node) => node is T_2) | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        universal?: boolean | undefined;
        reverse?: boolean | undefined;
        voids?: boolean | undefined;
    }): Iterable<NodeEntry<T_2>>;
    parent(editor: Editor, at: import("../location").Location, options?: {
        depth?: number | undefined;
        edge?: "start" | "end" | undefined;
    }): NodeEntry<import("../node").Ancestor>;
    path(editor: Editor, at: import("../location").Location, options?: {
        depth?: number | undefined;
        edge?: "start" | "end" | undefined;
    }): import("../path").Path;
    point(editor: Editor, at: import("../location").Location, options?: {
        edge?: "start" | "end" | undefined;
    }): import("../point").Point;
    positions(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        unit?: "offset" | "character" | "word" | "line" | "block" | undefined;
        reverse?: boolean | undefined;
    }): Iterable<import("../point").Point>;
    previous<T_3 extends Node>(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        match?: ((node: Node) => boolean) | ((node: Node) => node is T_3) | undefined;
        mode?: "highest" | "lowest" | "all" | undefined;
        voids?: boolean | undefined;
    }): NodeEntry<T_3> | undefined;
    range(editor: Editor, at: import("../location").Location, to?: Range | import("../path").Path | import("../point").Point | undefined): Range;
    start(editor: Editor, at: import("../location").Location): import("../point").Point;
    text(editor: Editor, at: import("../location").Location): string;
    void(editor: Editor, options?: {
        at?: Range | import("../path").Path | import("../point").Point | undefined;
        mode?: "highest" | "lowest" | undefined;
        voids?: boolean | undefined;
    }): NodeEntry<Element> | undefined;
    normalize(editor: Editor, options?: {
        force?: boolean | undefined;
    }): void;
    transform(editor: Editor, op: Operation): void;
    isBlock(editor: Editor, value: any): value is Element;
    isEditor(value: any): value is Editor;
    isInline(editor: Editor, value: any): value is Element;
    isNormalizing(editor: Editor): boolean;
    isVoid(editor: Editor, value: any): value is Element;
    marks(editor: Editor): Record<string, any> | null;
    pathRef(editor: Editor, path: import("../path").Path, options?: {
        affinity?: "backward" | "forward" | null | undefined;
    }): import("../path-ref").PathRef;
    pathRefs(editor: Editor): Set<import("../path-ref").PathRef>;
    pointRef(editor: Editor, point: import("../point").Point, options?: {
        affinity?: "backward" | "forward" | null | undefined;
    }): import("../point-ref").PointRef;
    pointRefs(editor: Editor): Set<import("../point-ref").PointRef>;
    rangeRef(editor: Editor, range: Range, options?: {
        affinity?: "backward" | "forward" | "outward" | "inward" | null | undefined;
    }): import("../range-ref").RangeRef;
    rangeRefs(editor: Editor): Set<import("../range-ref").RangeRef>;
    withoutNormalizing(editor: Editor, fn: () => void): void;
    hasBlocks(editor: Editor, element: Element): boolean;
    hasInlines(editor: Editor, element: Element): boolean;
    hasTexts(editor: Editor, element: Element): boolean;
    isEmpty(editor: Editor, element: Element): boolean;
};
//# sourceMappingURL=index.d.ts.map